@@ -82,14 +82,21 @@ set_parameter_matrix <- function(model, P = NULL) {
 print.parameter_matrix <- function(x, ...) {
   cat(paste0("\nRows are parameters, grouped in parameter sets"))
   cat(paste0("\n\nColumns are causal types"))
-  cat(paste0("\n\nCell entries indicate whether a parameter probability is",
-             "used\nin the calculation of causal type probability\n\n"))
+  cat(
+    paste0(
+      "\n\nCell entries indicate whether a parameter probability is",
+      "used\nin the calculation of causal type probability\n\n"
+    )
+  )
 
-  param_set <- attr(x, "param_set")
   class(x) <- "data.frame"
   print(x)
-  cat("\n \n param_set  (P)\n ")
-  cat(paste0(param_set, collapse = "  "))
+  cat("\n")
+  if (!is.null(attr(x, "param_set"))) {
+    param_set <- attr(x, "param_set")
+    cat("\n param_set  (P)\n ")
+    cat(paste0(param_set, collapse = "  "))
+  }
   return(invisible(x))
 }
 
