@@ -21,14 +21,9 @@ testthat::test_that(
 		model <- make_model('X -> Y')
 		query <- '(Y[X=1] > Y[X=0]) & (X == 0)'
 		x <- map_query_to_causal_type(model, query)
-		out <- capture.output(CausalQueries:::print.summary.causal_types(x))
-		expect_equal(length(out), 10)
+		out <- capture.output(print(x))
+		expect_equal(out[[9]], " Number of causal types that meet condition(s) =  1")
 
-		# Other objects
-		x <- list()
-		class(x) <- "causal_type"
-		out <- capture.output(CausalQueries:::print.summary.causal_types(x))
-		expect_equal(out[1], "list()")
 	}
 )
 
