@@ -20,12 +20,28 @@ testthat::test_that(
 		expect_equal(out[1], "(B[A=1] < B[A=0])")
 		out <- non_increasing("A", "B")
 		expect_equal(out[1], "(B[A=1] <= B[A=0])")
+
 		out <- interacts("X", "W", "Y")
-		expect_equal(out[1], "((Y[X =1, W = 1]) - (Y[X = 0, W = 1])) != ((Y[X =1, W = 0]) - (Y[X = 0, W = 0]))")
+		expect_equal(out[1],
+		             paste(
+		               "((Y[X =1, W = 1]) - (Y[X = 0, W = 1])) !=",
+		               "((Y[X =1, W = 0]) - (Y[X = 0, W = 0]))"
+		             ))
+
 		out <- complements("X", "W", "Y")
-		expect_equal(out[1], "((Y[X =1, W = 1]) - (Y[X = 0, W = 1])) > ((Y[X =1, W = 0]) - (Y[X = 0, W = 0]))")
+		expect_equal(out[1],
+		             paste(
+		               "((Y[X =1, W = 1]) - (Y[X = 0, W = 1])) >",
+		               "((Y[X =1, W = 0]) - (Y[X = 0, W = 0]))"
+		             ))
+
 		out <- substitutes("X", "W", "Y")
-		expect_equal(out[1], "((Y[X = 1, W = 1]) - (Y[X = 0, W = 1])) < ((Y[X = 1, W = 0]) - (Y[X = 0, W = 0]))")
+		expect_equal(out[1],
+		             paste(
+		               "((Y[X = 1, W = 1]) - (Y[X = 0, W = 1])) <",
+		               "((Y[X = 1, W = 0]) - (Y[X = 0, W = 0]))"
+		             ))
+
 		out <- te("A", "B")
 		expect_equal(out[1], "(B[A=1] - B[A=0])")
 	}
